
.. image:: http://genomicsandhealth.org/files/logo_ga.png

==============================
GA4GH Reference Implementation
==============================

This is the GA4GH reference implementation.

Full documentation is available at `read-the-docs.org
<http://ga4gh-server.readthedocs.org/en/stable>`_.

- For a quick start with the GA4GH API, please see our
  `demo <http://ga4gh-server.readthedocs.org/en/stable/demo.html>`_.
- To configure and deploy the GA4GH server in production
  please see the
  `installation
  <http://ga4gh-server.readthedocs.org/en/stable/installation.html>`_
  page.
- If you would like to contribute to the project, please see the
  `development
  <http://ga4gh-server.readthedocs.org/en/stable/development.html>`_
  page.
